import numpy as np

def twoNumArray(x, y):
  arr = np.array([x, y])
  print(arr)

def threeNumArray(x, y, z):
  arr = np.array([x, y, z])
  print(arr)

def fourNumArray(a, b, c, d):
  arr = np.array([a, b, c, d])
  print(arr)

def fiveNumArray(a, b, c, d, e):
  arr = np.array([a, b, c, d, e])
  print(arr)